export declare const PREFIX: string;
export declare const EXTRA_TIME_FOR_TRANSITION = 60;
export declare const TRANSITION_TIME = 300;
export declare const TRANSITION_STATE_CLASSNAME = "colexping";
export declare const INIT_CLASSNAME: string;
export declare const CONTAINER_ATTR: string;
export declare const CONTAINER_SELECTOR: string;
export declare const ACCORDION_ITEM_WRAPPER_ATTR: string;
export declare const ACCORDION_ITEM_WRAPPER_SELECTOR: string;
export declare const ACCORDION_ATTR: string;
export declare const ACCORDION_SELECTOR: string;
export declare const TRIGGER_ATTR: string;
export declare const TRIGGER_SELECTOR: string;
export declare const COLLAPSE_ATTR: string;
export declare const TOGGLE_TYPE_ATTR: string;
export declare const DURATION_ATTR: string;
export declare const DURATION_CSS_VAR: string;
export declare const EXPANDED_CSS_CLASS = "expanded";
export declare const COLLAPSED_CSS_CLASS = "collapsed";
export declare const DATA_WRAPPER_SELECTOR_ATTR: string;
export declare const DATA_ACCORDION_SELECTOR_ATTR: string;
export declare const DATA_TRIGGER_SELECTOR_ATTR: string;
export declare function isContainer(element: Element): boolean;
export declare function SELECT_TRIGGER_ACCORDION(selector: string): string;
/**
 * @param wrapperEl - accordion wrapper element
 * @param wrapperSelector - wrapper css selector
 * @param accordionSelector - accordion css selector
 * @param triggerSelector - trigger css selector
 * @param collapsed - will accordion be collapsed or not (default: true)
 * @returns true if everything is good or false unless otherwise
 * @description it will init every accordions and triggers inside wrapper element
 */
export declare function initWrapper(wrapperEl: unknown, wrapperSelector: string, accordionSelector: string, triggerSelector?: undefined | null | string, collapsed?: boolean): boolean;
export declare function initAccordion(accordion: HTMLElement, initCollapse?: boolean): void;
export declare function getContainer(accordion: HTMLElement): HTMLElement | undefined;
/**
 * @param wrapperEl - accordion wrapper element
 * @param wrapperSelector - wrapper css selector
 * @param accordionSelector - accordion css selector
 * @returns Accordion Element if found one
 * @description find accordion inside wrapper (not nested wrapper)
 */
export declare function findAccordionInsideWrapper(wrapperEl: HTMLElement, wrapperSelector: string, accordionSelector?: string): null | HTMLElement;
/**
 * @param container - accordions container
 * @returns wrapper css selector
 * @description it will get wrapper selector string from container data attribute,
 * the attribute has set when new instance of accordion was created
 */
export declare function getWrapperSelector(container: HTMLElement): string;
/**
 * @param container - accordions container
 * @returns accordon css selector
 * @description it will get accordion selector string from container data attribute,
 * the attribute has set when new instance of accordion was created
 */
export declare function getAccordionSelector(container: HTMLElement): string;
/**
 * @param container - accordions container
 * @returns trigger css selector
 * @description it will get trigger selector string from container data attribute,
 * the attribute has set when new instance of accordion was created
 */
export declare function getTriggerSelector(container: HTMLElement): string;
export declare function getTransitionDuration(container: HTMLElement): number | undefined;
export declare function getRelativeAccordions(accordion: HTMLElement): HTMLElement[] | null;
/**
 * returns true or false whether accordion is collapsed or not
 */
export declare function isAccordionCollapsed(accordion: HTMLElement): boolean;
export declare function beforeAccordionTransition(accordion: HTMLElement, callBackFunc?: Function): void;
export declare function afterAccordionTransitionFinish(accordion: HTMLElement, callBackFunc?: Function): void;
export declare function isAccordionsTransitioning(accordion: HTMLElement): boolean;
export declare function getAccordionType(element: HTMLElement): string | null | undefined;
/**
 * @param accordionContainer - container element of accordion
 * @param position - number of the accordion from top
 * @returns HTMLElement | null whether if succeed or not
 * @description find accordion in the container from top position
 */
export declare function findAccordionWithPosition(accordionContainer: HTMLElement, position: number): HTMLElement | null;
/**
 * @param element - which element to toggle classes
 * @param isCollapsed - whether accordion is collapsed or not. (default true)
 * @description add collapse CSS class and remove expand CSS class and
 * vice-versa if `isCollapsed` is false
 */
export declare function toggleActiveCSSClass(element: Element, isCollapsed?: boolean): void;
